#!/usr/bin/env python3

# Copyright 2017 Jose Nelson Amaral
# Copyright 2017 Elliot Colp
# Copyright 2017 Erick Ochoa Lopez
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
# 
# 1. Redistributions of source code must retain the above copyright notice, this
# list of conditions and the following disclaimer.
# 
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
# 
# 3. Neither the name of the copyright holder nor the names of its contributors
# may be used to endorse or promote products derived from this software without
# specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

"""
Prints information about the game length for all SGFs in the given directory.
"""


import random, glob, re, sys
from pylab import *

moveLen = []

for game in glob.glob(sys.argv[1] + "/*.sgf"):
    # Read the game string
    with open(game, "r") as gameFile:
        gameStr = gameFile.read()
        
    moves = []
    
    # Handle handicap move
    moveStart = gameStr.find("AB[")
    if moveStart > -1:
        # Find white's move
        normalStart = gameStr.find(";W[")
        
        # Include the black handicap placement as a move
        moves.append(gameStr[moveStart:normalStart])
    else:
        # Normal start
        normalStart = gameStr.find(";B[")
        moveStart = normalStart
    
    # Get the list of moves
    moves += (re.findall(r"[BW]\[[^\]]*\]", gameStr[normalStart:]))
    
    moveLen.append(len(moves))
    
print("Min:", min(moveLen))
print("Max:", max(moveLen))
print("Mean:", mean(moveLen))
print("STD:", std(moveLen))
